[![PyPI version](https://badge.fury.io/py/listcolouring.svg)](https://badge.fury.io/py/listcolouring)
![python package](https://github.com/MHenderson/listcolouring/actions/workflows/python-package.yml/badge.svg)
![python publish](https://github.com/MHenderson/listcolouring/actions/workflows/python-publish.yml/badge.svg)

# listcolouring

List colouring of graphs in Python.

